MemorySection

Struct MemorySection 

pub struct MemorySection { /* private fields */ }

Implementations

Source

impl MemorySection

pub fn new(name: impl Into<String>, origin: u64, length: u64) -> MemorySection

pub fn offset(self, offset: u64) -> MemorySection

pub fn pagesize(self, pagesize: u64) -> MemorySection

pub fn slot(self, slot: usize, num_slots: usize) -> MemorySection

Divide memory section into slots.

This can be used to divide a memory section into multiple slots of equal size, e.g., for an active / passive image scheme on MCUs.

slot starts at zero for the first slot.

pub fn from_env(self) -> MemorySection

Read options from environment

This will evaluate the following environment variables:

VariableDefault
LDMEMORY_OFFSET0
LDMEMORY_PAGESIZE1
LDMEMORY_NUM_SLOTS2
LDMEMORY_SLOT_OFFSET0
LDMEMORY_SLOTNone

If an offset is given, the whole section will be offset and shortened by the given value. If a pagesize is given, the slots will start and end will be aligned at the pagesize. If a slot number is given, the remaining section will be divided into <prefix>_NUM_SLOTS slots, aligned to <prefix>_PAGESIZE, and the <prefix>_SLOTth (starting at 0) will be returned. If a slot offset is given, each slot will be offset and shortened by that value.

Note: from_env_with_prefix can be used to use a different prefix than the default prefix LDMEMORY_.

pub fn from_env_with_prefix(self, prefix: &str) -> MemorySection

Read slot options from environment with custom prefix

See from_env().

pub fn attrs(self, attrs: &str) -> MemorySection

pub fn to_ldmemory(&self) -> String

pub fn start_symbol(&self) -> String

Creates a String with symbol for the start of the section

let section = MemorySection::new("FLASH", 0, 4096);
assert_eq!(section.start_symbol(), "_FLASH_start");
pub fn length_symbol(&self) -> String

Creates a String with symbol for the length of the section

let section = MemorySection::new("FLASH", 0, 4096);
assert_eq!(section.length_symbol(), "_FLASH_length");
pub fn ldmemory_start_symbol(&self) -> String

Creates the line for the linker script with the start of the symbol.

let section = MemorySection::new("FLASH", 0, 4096);
assert_eq!(section.ldmemory_start_symbol(), "_FLASH_start = 0x0;");
pub fn ldmemory_length_symbol(&self) -> String

Creates the line for the linker script with the length of the symbol.

let section = MemorySection::new("FLASH", 0, 4096);
assert_eq!(section.ldmemory_length_symbol(), "_FLASH_length = 0x1000;");
pub fn get_name(&self) -> &String

Get this section’s name.

pub fn get_length(&self) -> u64

Get this section’s length.

pub fn get_origin(&self) -> u64

Get this section’s origin.

pub fn get_attrs(&self) -> Option<&String>

Get this section’s attributes.

pub fn get_pagesize(&self) -> u64

Get this section’s pagesize.